@@ -1,5 +1,5 @@
 package Text::Password::MD5;
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 use Moose;
 extends 'Text::Password::CoreCrypt';
@@ -68,7 +68,7 @@ override 'verify' => sub {
 
      die __PACKAGE__. " doesn't allow any Wide Characters or white spaces\n"
     if $input !~ /[!-~]/ or $input =~ /\s/;
-     croak "Crypt::PasswdMD5 makes 34bytes hash strings. Your data must be wrong."
+     croak "Crypt::PasswdMD5 makes 34bytes hash strings. Your data must be wrong"
     if $data !~ /^\$1\$[!-~]{1,8}\$[!-~]{22}$/;
 
     return $data eq unix_md5_crypt( $input, $data );
@@ -97,8 +97,9 @@ override 'encrypt' => sub {
     if $input !~ /[!-~]/ or $input =~ /\s/;
 
     my $salt = shift || $self->nonce();
-    carp "warning: short lengths salt is set. you don't have to." if length($salt) < 8;
-    carp "warning: too many string lengths for salt. unix_md5_crypt() ignores more than 8." if $salt and length($salt) > 8;
+    carp "warning: short lengths salt is set. you don't have to" if length($salt) < 8;
+     carp "warning: too many string lengths for salt. unix_md5_crypt() ignores more than 8"
+    if $salt and length($salt) > 8;
 
     return unix_md5_crypt( $input, $salt );
 };
